(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8396,        234]*)
(*NotebookOutlinePosition[      9041,        256]*)
(*  CellTagsIndexPosition[      8997,        252]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Astronomical Image Processing", "Subtitle"],

Cell[TextData[{
  "Astronomical image processing of CCD images typically involves the use of \
several images which, when combined, results in a reduced image ready for \
data analysis.  CCD chips can be thought of as an array of tiny voltage \
meters.  In theory, as photons hit the elements of the chip, they register a \
voltage.  The more photons, the more voltage and hence a brighter pixel.  In \
practice, the chip is not perfect and some elements are more sensitive than \
others.  Also, the chip itself has a bias voltage applied which raises the \
pixel value of every element. To complicate matters more, dust and dirt may \
lie in the light path which can block photons from hitting the CCD.  Since \
these dust particles do not lie at the focal point, they appear in the image \
as unfocused doughnuts.\n The initial frames include a raw image frame, a \
flat-field frame, a bias frame (a.k.a zero frame), and sometimes a dark \
frame.  \n ",
  StyleBox["Raw Image Frame",
    FontWeight->"Bold"],
  ": The raw image frame includes the light from the object being observed, \
but also includes the effects of dirt and dust in the light path of the \
telescope.\n ",
  StyleBox["Flat-field Frame",
    FontWeight->"Bold"],
  ": Taken against a uniformly illuminated background source, this should, in \
theory, result in a \"flat field\", free of any brightness deviations.  In \
practice, sensitivity variations and dust particles are seen and mapped for \
later removal.\n ",
  StyleBox["Bias Frame",
    FontWeight->"Bold"],
  ":  Zero length \"exposure\" that simply reads out the CCD and hence \
measures only the brightness of the pixels resulting from the applied \
voltage.\n ",
  StyleBox["Dark Frame",
    FontWeight->"Bold"],
  ": Although not included here, this frame measures the contribution from \
thermal electrons resulting from heat.  The camera used for the images here \
was cooled with liquid nitrogen and so the dark frame is ignored since the \
contribution is minimal."
}], "Text"],

Cell["First, we import the frames, all in FITS format.", "Text"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(rawimage = Import["\<May08_0132.fit\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(avgvflat = Import["\<avgvflat.fit\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(avgbias = Import["\<avgbias.fit\>"];\)\)], "Input"],

Cell["\<\
Here we can see a raw image frame of the giant elliptical galaxy M87.  \
Visible are the source object, many \"dust doughnuts\", and an overscan \
region which can be used for calibration, but is not needed here.\
\>", "Text"],

Cell[BoxData[
    \(\(fawimagegr = 
        ListDensityPlot[rawimage[\([1]\)], Mesh \[Rule] False, 
          ImageSize \[Rule] 542];\)\)], "Input"],

Cell["\<\
All of the images contain a useful imaging region that is 512x512 pixels.  It \
is useful to crop the overscan region out of all the images and so the \
following function strips the overscan region from an image.\
\>", "Text"],

Cell[BoxData[
    \(RemoveOverscan[data_] := 
      Transpose[Take[Transpose[data], {1, 512}]]\)], "Input"],

Cell[BoxData[
    \(\(croppedimage = RemoveOverscan[rawimage[\([1]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(croppedflat = RemoveOverscan[avgvflat[\([1]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(croppedbias = RemoveOverscan[avgbias[\([1]\)]];\)\)], "Input"],

Cell["\<\
Here, we can see the raw image frame with the overscan region removed.\
\>", "Text"],

Cell[BoxData[
    \(croppedimagegr = 
      ListDensityPlot[croppedimage, Mesh \[Rule] False, 
        ImageSize \[Rule] 512]\)], "Input"],

Cell[BoxData[
    \(Export["\<rawimage.jpg\>", croppedimagegr]\)], "Input"],

Cell["\<\
Similarly, we can do the same with the flat-field image.  It is fairly \
obvious that the CCD chip has noticeable sensitivity variations and \
noticeable dust contamination.  These will be compensated for later.\
\>", "Text"],

Cell[BoxData[
    \(croppedflatgr = 
      ListDensityPlot[croppedflat, Mesh \[Rule] False, 
        ImageSize \[Rule] 512]\)], "Input"],

Cell[BoxData[
    \(Export["\<flat.jpg\>", croppedflatgr]\)], "Input"],

Cell["\<\
The bias frame is not plotted since it is essentially a flat voltage and \
isn't interesting to look at.  However, its contribution needs to be removed \
from all frames, including the image frame and the flat-field.  The following \
code subtracts the bias frame from the flat-field frame and normalizes the \
resulting frame.\
\>", "Text"],

Cell[BoxData[
    \(\(normalizedflat = \((croppedflat - croppedbias)\)/
          Max[Flatten[\((croppedflat - croppedbias)\)]];\)\)], "Input"],

Cell["\<\
Next, we subtract the bias frame from the raw image frame and then divide by \
the normalized flat-field frame.  This last operation effectively removes the \
contribution from the dust and sensitivity variations.\
\>", "Text"],

Cell[BoxData[
    \(\(reducedimage = 
        N[\((croppedimage - croppedbias)\)/normalizedflat];\)\)], "Input"],

Cell["\<\
The reduced image frame can now be viewed, free from defects.\
\>", "Text"],

Cell[BoxData[
    \(reducedgr = 
      ListDensityPlot[reducedimage, Mesh \[Rule] False, 
        ImageSize \[Rule] 512]\)], "Input"],

Cell[BoxData[
    \(Export["\<reduced.jpg\>", reducedgr]\)], "Input"],

Cell["\<\
The brightness of this galaxy obscures some of the fine detail hidden in the \
glare.  We can compensate for this by adjusting the contrast using PlotRange \
to limit the brightness values we see.  The following contrast adjustment \
reveals the core of the galaxy with an apparent object protruding from the \
center.\
\>", "Text"],

Cell[BoxData[
    \(contrastgr = 
      ListDensityPlot[reducedimage, Mesh \[Rule] False, 
        PlotRange \[Rule] {0, 5000}, Frame \[Rule] False, 
        ImageSize \[Rule] 512]\)], "Input"],

Cell[BoxData[
    \(Export["\<contrast.jpg\>", contrastgr]\)], "Input"],

Cell["\<\
We can zoom into the central region by adjusting the PlotRange further.  The \
protruding object is actually a jet of material being emitted by a \
supermassive black hole at the core of M87.\
\>", "Text"],

Cell[BoxData[
    \(zoomgr = 
      ListDensityPlot[reducedimage, 
        PlotRange \[Rule] {{210, 310}, {150, 250}, {0, 5000}}, 
        Mesh \[Rule] False, Frame \[Rule] False, 
        ImageSize \[Rule] 512]\)], "Input"],

Cell[BoxData[
    \(Export["\<zoom.jpg\>", zoomgr]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
WindowSize->{743, 740},
WindowMargins->{{71, Automatic}, {Automatic, 15}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 49, 0, 51, "Subtitle"],
Cell[1828, 55, 2018, 36, 299, "Text"],
Cell[3849, 93, 64, 0, 33, "Text"],
Cell[3916, 95, 183, 4, 30, "Input"],
Cell[4102, 101, 77, 1, 30, "Input"],
Cell[4182, 104, 75, 1, 30, "Input"],
Cell[4260, 107, 73, 1, 30, "Input"],
Cell[4336, 110, 236, 4, 52, "Text"],
Cell[4575, 116, 148, 3, 30, "Input"],
Cell[4726, 121, 237, 4, 52, "Text"],
Cell[4966, 127, 107, 2, 30, "Input"],
Cell[5076, 131, 86, 1, 30, "Input"],
Cell[5165, 134, 85, 1, 30, "Input"],
Cell[5253, 137, 84, 1, 30, "Input"],
Cell[5340, 140, 94, 2, 33, "Text"],
Cell[5437, 144, 138, 3, 30, "Input"],
Cell[5578, 149, 75, 1, 30, "Input"],
Cell[5656, 152, 235, 4, 52, "Text"],
Cell[5894, 158, 136, 3, 30, "Input"],
Cell[6033, 163, 70, 1, 30, "Input"],
Cell[6106, 166, 351, 6, 71, "Text"],
Cell[6460, 174, 143, 2, 30, "Input"],
Cell[6606, 178, 237, 4, 52, "Text"],
Cell[6846, 184, 112, 2, 30, "Input"],
Cell[6961, 188, 85, 2, 33, "Text"],
Cell[7049, 192, 133, 3, 30, "Input"],
Cell[7185, 197, 69, 1, 30, "Input"],
Cell[7257, 200, 342, 6, 71, "Text"],
Cell[7602, 208, 193, 4, 50, "Input"],
Cell[7798, 214, 71, 1, 30, "Input"],
Cell[7872, 217, 215, 4, 52, "Text"],
Cell[8090, 223, 224, 5, 50, "Input"],
Cell[8317, 230, 63, 1, 30, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

